==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PropertyUpdatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescription } from "./PropertyUpdatedEventArgsDescription";
/**
 * @hidden
 */
var PropertyUpdatedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyUpdatedEventArgsDescriptionMetadata, _super);
    function PropertyUpdatedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyUpdatedEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyUpdatedEventArgsDescriptionMetadata.a == null) {
            PropertyUpdatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyUpdatedEventArgsDescriptionMetadata.c(PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
        if (a.g(PropertyUpdatedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.c = function (a) {
        a.item("PropertyName", "String");
        a.item("OldValueRef", "(w:OldValue,wf:OldValue)DataRef");
        a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef");
    };
    PropertyUpdatedEventArgsDescriptionMetadata.d = function (a) {
        PropertyUpdatedEventArgsDescriptionMetadata.b(a);
        a.u("PropertyUpdatedEventArgs", function () { return new PropertyUpdatedEventArgsDescription(); });
        a.t("PropertyUpdatedEventArgs", PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.$t = markType(PropertyUpdatedEventArgsDescriptionMetadata, 'PropertyUpdatedEventArgsDescriptionMetadata');
    PropertyUpdatedEventArgsDescriptionMetadata.a = null;
    return PropertyUpdatedEventArgsDescriptionMetadata;
}(Base));
export { PropertyUpdatedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PropertyUpdatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescription } from "./PropertyUpdatedEventArgsDescription";
/**
 * @hidden
 */
var PropertyUpdatedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyUpdatedEventArgsDescriptionMetadata, _super);
    function PropertyUpdatedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyUpdatedEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyUpdatedEventArgsDescriptionMetadata.a == null) {
            PropertyUpdatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyUpdatedEventArgsDescriptionMetadata.c(PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
        if (a.j(PropertyUpdatedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.c = function (a) {
        a.item("PropertyName", "String");
        a.item("OldValueRef", "(w:OldValue,wf:OldValue)DataRef");
        a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef");
    };
    PropertyUpdatedEventArgsDescriptionMetadata.d = function (a) {
        PropertyUpdatedEventArgsDescriptionMetadata.b(a);
        a.aa("PropertyUpdatedEventArgs", function () { return new PropertyUpdatedEventArgsDescription(); });
        a.z("PropertyUpdatedEventArgs", PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.$t = markType(PropertyUpdatedEventArgsDescriptionMetadata, 'PropertyUpdatedEventArgsDescriptionMetadata');
    PropertyUpdatedEventArgsDescriptionMetadata.a = null;
    return PropertyUpdatedEventArgsDescriptionMetadata;
}(Base));
export { PropertyUpdatedEventArgsDescriptionMetadata };
